/****************************************************************************
 *
 * Copyright (c) 2010-2012, EBM WebSourcing
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
 *
 *****************************************************************************/

package org.ow2.petals.cli.api.command.exception;

import org.apache.commons.cli.Option;
import org.ow2.petals.cli.api.command.Command;

/**
 * Exception thrown when an argument of an option has an unparsable value.
 * 
 * @author Christophe DENEUX - Linagora
 */
public class CommandUnparsableArgumentException extends CommandInvalidException {

    private static final long serialVersionUID = 7144591830221248099L;

    public final static String UNPARSABLE_ARGUMENT_VALUE = "Argument value of option '-%s' has an unparsable value '%s'";

    /**
     * The option for which the argument has an invalid value.
     */
    private final Option option;

    /**
     * The unparsable value.
     */
    private final String unparsableValue;

    public CommandUnparsableArgumentException(final Command command, final Option option,
            final String unparsableValue) {
        super(command, String.format(UNPARSABLE_ARGUMENT_VALUE, option.getOpt(), unparsableValue));
        this.option = option;
        this.unparsableValue = unparsableValue;
    }

    /**
     * @return The option for which the argument has an invalid value.
     */
    public Option getOption() {
        return this.option;
    }

    /**
     * @return The unparsable value.
     */
    public String getUnparsableValue() {
        return this.unparsableValue;
    }

}
